# Initialize Configuration


::: flyvis_cli.init_config
    options:
      heading_level: 4


```
usage: init_config.py [-h] [--output-dir OUTPUT_DIR]
                      [--config-groups [CONFIG_GROUPS ...]]

Initialize a local config directory with defaults from the package

options:
  -h, --help            show this help message and exit
  --output-dir OUTPUT_DIR
                        Directory where config should be initialized
  --config-groups [CONFIG_GROUPS ...]
                        Specific config groups to initialize (e.g.,
                        network/edge_config/syn_strength). If none specified,
                        copies all.

```
